| em_lfdr | R Documentation |
Estimate the local false discovery rate across two studies and apply a step-up procedure to control the FDR of replicability null.
em_lfdr(pa_in, pb_in, pi0a_in, pi0b_in)
pa_in |
A numeric vector of p-values from study 1. |
pb_in |
A numeric vector of p-values from study 2. |
pi0a_in |
An initial estimate of the null probability in study 1. |
pi0b_in |
An initial estimate of the null probability in study 2. |
Lfdr |
The estimated local false discovery rate for replicability null. |
fdr |
The adjusted values based on local false discovery rate for FDR control. |
xi00 |
An estimate of the prior probability for joint state (0, 0). |
xi01 |
An estimate of the prior probability for joint state (0, 1). |
xi10 |
An estimate of the prior probability for joint state (1, 0). |
xi11 |
An estimate of the prior probability for joint state (1, 1). |
f1 |
A non-parametric estimate for the non-null probability density function in study 1. |
f2 |
A non-parametric estimate for the non-null probability density function in study 2. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.